use strict;
use warnings;
use inc::Module::Install;

name 'CatalystX-state51-LegacySupport';
all_from 'lib/CatalystX/state51/LegacySupport.pm';

requires 'Catalyst::Runtime' => '5.80015';
requires 'Moose';
requires 'namespace::autoclean';
requires 'state51::Base';
requires 'Catalyst::Action::RenderView';
requires 'Try::Tiny';
requires 'Moose::Autobox';
requires 'autobox' => '2.71';

test_requires 'Test::WWW::Mechanize::Catalyst';
test_requires 'Test::More' => '0.88';
test_requires 'Catalyst::Plugin::Session';
test_requires 'Catalyst::Plugin::Session::Store::DBI';
test_requires 'Catalyst::Plugin::Session::State::Cookie';
test_requires 'Catalyst::View::TT';

resources repository => 'git://somewhere.com/myproject.git';

if ($Module::Install::AUTHOR) {
    system("pod2text lib/CatalystX/state51/LegacySupport.pm > README")
        and die $!;
}

sub MY::test_via_harness {
    local $_ = shift()->MM::test_via_harness( @_ );
    s/\bPERL_DL_NONLAZY=1 +//g;
    return $_;
}

sub MY::test_via_script {
    local $_ = shift()->MM::test_via_script( @_ );
    s/\bPERL_DL_NON_LAZY=1 +//g;
    return $_;
}

WriteAll();

eval {
    use FindBin qw/$Bin/;
    use Data::UUID;

    my $ug = Data::UUID->new;
    my $uuid = $ug->create();
    my $uuid_string = sprintf("%s-", $ug->to_string($uuid));

    my $outfile = "$Bin/t/lib/TestConfig.pm";
    open(TESTCONFIG, '>', $outfile) or die("Could not write to $outfile");
    print TESTCONFIG qq(package TestConfig;
use strict;
use warnings;
sub file_key_prefix {
    return  "$uuid_string";
}

our \$BASE_DN = 'dc=cissme,dc=com';

our \$LDAP_ADMIN_UID='t0m';
our \$LDAP_ADMIN_DN='uid=t0m,ou=State51,ou=Staff,dc=cissme,dc=com';
our \$LDAP_ADMIN_PASSWORD='test';

our \$LDAP_USER_UID='andym';
our \$LDAP_USER_PASSWORD='test';

);

    print TESTCONFIG "1;\n";

    close(TESTCONFIG);
};
warn "Could not write config for the test suite: $@" if $@;

